﻿using System;
using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;

namespace HeuristicLab.Problems.ExternalEvaluation.Views {

  [View("EvaluationCacheView")]
  [Content(typeof(EvaluationCache), IsDefaultView = true)]
  public sealed partial class EvaluationCacheView : ParameterizedNamedItemView {

    public new EvaluationCache Content {
      get { return (EvaluationCache)base.Content; }
      set { base.Content = value; }
    }

    public EvaluationCacheView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      Content.SizeChanged -= new System.EventHandler(Content_StatusChanged);
      Content.HitsChanged -= new System.EventHandler(Content_StatusChanged);
      base.DeregisterContentEvents();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.SizeChanged += new System.EventHandler(Content_StatusChanged);
      Content.HitsChanged += new System.EventHandler(Content_StatusChanged);
    }

    #region Event Handlers (Content)
    void Content_StatusChanged(object sender, EventArgs e) {
      if (InvokeRequired)
        Invoke(new EventHandler(Content_StatusChanged), sender, e);
      else
        hits_sizeTextBox.Text = string.Format("{0}/{1}", Content.Hits, Content.Size);
    }

    #endregion

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        hits_sizeTextBox.Text = "#/#";
      } else {
        Content_StatusChanged(this, EventArgs.Empty);
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      clearButton.Enabled = !ReadOnly && Content != null;
    }

    #region Event Handlers (child controls)
    private void clearButton_Click(object sender, EventArgs e) {
      Content.Reset();
    }
    #endregion
  }
}
